==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/pl/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Ten użytkownik może się zalogować',
    'activated_disabled_help_text' => 'Nie możesz edytować statusu aktywacji dla własnego konta.',
    'assets_user'       => 'Aktywa przypisane do :name',
    'bulk_update_warn'	=> 'Zamierzasz edytować właściwości: user_count użytkowników. Należy pamiętać, że nie można zmienić własne atrybuty użytkownika, korzystając z tego formularza i musi przeprowadzić edycję własnych użytkownika indywidualnie.',
    'bulk_update_help'	=> 'Ten formularz umożliwia zbiorczą aktualizację wielu aktywów na raz. Wypełnij tylko te pola, które chcesz zmienić. Puste pola pozostaną niezmienione.',
    'current_assets'    => 'Aktywo obecnie jest przypisane do tego użytkownika',
    'clone'             => 'Kopiuj Użytkownika',
    'contact_user'      => 'Kontakt :name',
    'edit'              => 'Edycja Użytkownika',
    'filetype_info'     => 'Dozwolone typy plików: png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, rar.',
    'history_user'      => 'Historia',
	'info'				=> 'Informacje',
    'restore_user'		=> 'Kliknij tutaj, aby je przywrócić.',
    'last_login'        => 'Ostatnie logowanie',
    'ldap_config_text'  => 'Ustawienia konfiguracji LDAP mogą być znalezione w Administracja -> Ustawienia. Opcjonalnie wybierz lokalizacje, która będzie ustawiona dla zaimportowanych użytkowników.',
    'print_assigned'    => 'Drukuj wszystko przypisane',
    'software_user'     => 'Oprogramowanie przypisane do :name',
    'send_email_help'   => 'Musisz podać adres e-mail dla tego użytkownika, aby wysłać mu poświadczenia. Wysłanie danych logowania jest możliwe tylko w czasie tworzenia użytkownika. Hasła są zaszyfrowane i nie można ich odzyskać po zapisaniu.',
    'view_user'         => 'Zobacz Użytkownika :name',
    'usercsv'           => 'plik CSV',
    'two_factor_admin_optin_help' => 'Bieżące ustawienia administracyjne pozwalają na wybiórcze rejestrowanie uwierzytelniania dwuskładnikowego.  ',
    'two_factor_enrolled' => 'Zarejestrowane urządzenie 2FA ',
    'two_factor_active'   => 'Aktywuj 2FA ',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/pl/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Ten użytkownik może się zalogować',
    'activated_disabled_help_text' => 'Nie możesz edytować statusu aktywacji dla własnego konta.',
    'assets_user'       => 'Aktywa przypisane do :name',
    'bulk_update_warn'	=> 'Zamierzasz edytować właściwości: user_count użytkowników. Należy pamiętać, że nie można zmienić własne atrybuty użytkownika, korzystając z tego formularza i musi przeprowadzić edycję własnych użytkownika indywidualnie.',
    'bulk_update_help'	=> 'Ten formularz umożliwia zbiorczą aktualizację wielu aktywów na raz. Wypełnij tylko te pola, które chcesz zmienić. Puste pola pozostaną niezmienione.',
    'current_assets'    => 'Aktywo obecnie jest przypisane do tego użytkownika',
    'clone'             => 'Kopiuj Użytkownika',
    'contact_user'      => 'Kontakt :name',
    'edit'              => 'Edycja Użytkownika',
    'filetype_info'     => 'Dozwolone typy plików: png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, rar.',
    'history_user'      => 'Historia',
    'info'				=> 'Informacje',
    'restore_user'		=> 'Kliknij tutaj, aby je przywrócić.',
    'last_login'        => 'Ostatnie logowanie',
    'ldap_config_text'  => 'Ustawienia konfiguracji LDAP mogą być znalezione w Administracja -> Ustawienia. Opcjonalnie wybierz lokalizacje, która będzie ustawiona dla zaimportowanych użytkowników.',
    'print_assigned'    => 'Drukuj wszystko przypisane',
    'software_user'     => 'Oprogramowanie przypisane do :name',
    'send_email_help'   => 'Musisz podać adres e-mail dla tego użytkownika, aby wysłać mu poświadczenia. Wysłanie danych logowania jest możliwe tylko w czasie tworzenia użytkownika. Hasła są zaszyfrowane i nie można ich odzyskać po zapisaniu.',
    'view_user'         => 'Zobacz Użytkownika :name',
    'usercsv'           => 'plik CSV',
    'two_factor_admin_optin_help' => 'Bieżące ustawienia administracyjne pozwalają na wybiórcze rejestrowanie uwierzytelniania dwuskładnikowego.  ',
    'two_factor_enrolled' => 'Zarejestrowane urządzenie 2FA ',
    'two_factor_active'   => 'Aktywuj 2FA ',
    'user_deactivated'  => 'Użytkownik jest dezaktywowany',
    'activation_status_warning' => 'Nie zmieniaj statusu aktywacji',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'OSTRZEŻENIE:',
    'warning_deletion_information' => 'Zamierzasz usunąć :count użytkowników wymienionych poniżej. Superadministratorzy zaznaczeni są na czerwono.',
    'update_user_asssets_status' => 'Zaktualizuj wszystkie zasoby dla tych użytkowników do tego statusu',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
